==> rest-sdk-0.1.0-sources.jar: com/mulesoft/connectivity/rest/sdk/internal/validation/rules/ConnectorNameMustBeFriendlyRule.java <==
/*
 * (c) 2003-2020 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package com.mulesoft.connectivity.rest.sdk.internal.validation.rules;

import static org.apache.commons.lang3.StringUtils.isNotBlank;
import static com.mulesoft.connectivity.rest.sdk.internal.util.NamingUtil.isFriendlyName;
import static com.mulesoft.connectivity.rest.sdk.internal.validation.ValidationRule.Level.ERROR;
import com.mulesoft.connectivity.rest.sdk.internal.descriptor.model.ConnectorDescriptor;
import com.mulesoft.connectivity.rest.sdk.internal.validation.PreValidationRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.ValidationResult;
import com.mulesoft.connectivity.rest.sdk.internal.webapi.model.APIModel;

import java.util.LinkedList;
import java.util.List;

public class ConnectorNameMustBeFriendlyRule extends PreValidationRule {

  //R011
  public ConnectorNameMustBeFriendlyRule() {
    super("connectorName property seems not to be a friendly name",
          "The connectorName declared in the descriptor should be a human readable name separated with spaces.",
          ERROR);
  }

  @Override
  public List<ValidationResult> preValidate(ConnectorDescriptor connectorDescriptor, APIModel apiModel) {

    List<ValidationResult> validationResults = new LinkedList<>();

    String connectorName = connectorDescriptor.getConnectorName();

    if (isNotBlank(connectorName) && !isFriendlyName(connectorName)) {
      validationResults.add(getValidationError(connectorName));
    }

    return validationResults;
  }

  private ValidationResult getValidationError(String name) {
    return new ValidationResult(this, "connectorName : " + name);
  }
}

==> rest-sdk-0.1.6-sources.jar: com/mulesoft/connectivity/rest/sdk/internal/validation/rules/ConnectorNameMustBeFriendlyRule.java <==
/*
 * (c) 2003-2021 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package com.mulesoft.connectivity.rest.sdk.internal.validation.rules;

import static org.apache.commons.lang3.StringUtils.isNotBlank;
import static com.mulesoft.connectivity.rest.sdk.internal.connectormodel.util.NamingUtil.isFriendlyName;
import static com.mulesoft.connectivity.rest.sdk.internal.validation.ValidationRule.Level.ERROR;
import com.mulesoft.connectivity.rest.sdk.internal.descriptor.model.ConnectorDescriptor;
import com.mulesoft.connectivity.rest.sdk.internal.validation.PreValidationRule;
import com.mulesoft.connectivity.rest.sdk.internal.validation.ValidationError;
import com.mulesoft.connectivity.rest.sdk.internal.webapi.model.APIModel;

import java.util.LinkedList;
import java.util.List;

public class ConnectorNameMustBeFriendlyRule extends PreValidationRule {

  // R011
  public ConnectorNameMustBeFriendlyRule() {
    super("connectorName property seems not to be a friendly name",
          "The connectorName declared in the descriptor should be a human readable name separated with spaces.",
          ERROR);
  }

  @Override
  public List<ValidationError> preValidate(ConnectorDescriptor connectorDescriptor, APIModel apiModel) {

    List<ValidationError> validationErrors = new LinkedList<>();

    String connectorName = connectorDescriptor.getConnectorName();

    if (isNotBlank(connectorName) && !isFriendlyName(connectorName)) {
      validationErrors.add(getValidationError(connectorDescriptor));
    }

    return validationErrors;
  }

  private ValidationError getValidationError(ConnectorDescriptor connectorDescriptor) {
    return new ValidationError(this,
                               "connectorName : " + connectorDescriptor.getConnectorName(),
                               connectorDescriptor.getLocation());
  }
}
